==> PPDF_1_1.zip: PubMedPDF/include/favorite_functions.php <==
<?php

# ʸꥹȼ
	function GET_BIBLIO_NUM($user){
		include "conn.php";
		include "../style.php";
		
		$sql = "SELECT * FROM ".$T_TMP." WHERE tmp1='biblio' AND tmp2='".$user."'";
		$res = mysql_query($sql, $conn);
		$num = mysql_num_rows($res);
	
		echo "<br><div class=\"pt\">"._MD_BIBLIO."</div>";
		echo "\"".$num."\" "._MD_BIBLIO_EXIST."&nbsp;&nbsp;&nbsp;";
		echo "[<a href=\"biblio.php\">"._MD_BIBLIO_EXPORT."</a>]<br>";
	}


# Υեɽ
# 桼̾եID

	function GET_FDIR($user, $dir_id){
		include "conn.php";
		include "../style.php";

		$d = "";
		$pass = "";

		# get dir name
		$sql = "SELECT * FROM ".$T_FDIR." WHERE id='".$dir_id."'";
		$res = mysql_query($sql, $conn);
		if(mysql_num_rows($res) > 0){
			$row = mysql_fetch_array($res, MYSQL_ASSOC);
			$d = "(".$row["Name"].")";
			$pass = $row["Pass"]."[".$dir_id."]";
		}

		echo "<br><div class=\"pt\">"._MD_FAVORITE_DIRLIST."</div>";
		$sql = "SELECT * FROM ".$T_FDIR." WHERE Usr='".$user."' AND Pass='".$pass."'";
		$res = mysql_query($sql, $conn);
		while($row = mysql_fetch_array($res, MYSQL_ASSOC)){
			$d_id = $row["id"];
			$d_name = $row["Name"];
			
			$sql2 = "SELECT * FROM ".$T_FDATA." WHERE dir_id='".$d_id."'";
			$res2 = mysql_query($sql2, $conn);
			echo "[<a href=\"favorite.php?deld_id=".$d_id."\"><img src=\"images/delete.png\"></a>] ";
			echo "<a href=\"favorite.php?d_id=".$d_id."\">".$d_name."</a>(".mysql_num_rows($res2).")";
			
			$sql3 = "SELECT * FROM ".$T_FDIR." WHERE Usr='".$user."' AND Pass like '%[".$d_id."]%'";
			$res3 = mysql_query($sql3, $conn);
			if(mysql_num_rows($res3) > 0){
				echo "<table style=\"margin-left:20px\"><tr>";
				$i=0;
				while($row3 = mysql_fetch_array($res3, MYSQL_ASSOC)){
					$sql4 = "SELECT * FROM ".$T_FDATA." WHERE dir_id='".$row3["id"]."'";
					$res4 = mysql_query($sql4, $conn);
					if(!($i % 4)) echo "</tr><tr>";
					echo "<td style=\"width:20%\">";
					echo "[<a href=\"favorite.php?deld_id=".$row3["id"]."\"><img src=\"images/delete.png\"></a>] ";
					echo "<a href=\"favorite.php?d_id=".$row3["id"]."\">".$row3["Name"]."</a>(".mysql_num_rows($res4).")&nbsp;&nbsp;";
					echo "</td>";
					$i++;
				}
				echo "</tr></table><br>";
			}else{
				echo "<br>";
			}
		}
		if($pass != "")	echo "<a href=\"favorite.php?ptop=y\">Top</a><br>";
	}


# Υǡɽ
# 桼̾եID

	function GET_FDATA($user, $dir_id){
	
		include "conn.php";
		include "../style.php";

		# upload directory(relative pass)
		$sql = "SELECT * FROM ".$T_CONFIG." WHERE conf_name='updir2'";
		$res = mysql_query($sql, $conn);
		$row = mysql_fetch_array($res, MYSQL_ASSOC);

		$up_dir = $row["conf_value"];
		if(substr($up_dir,-1) != "/") $up_dir.="/";

		# get dir name
		$pass = "";
		$dir_map = "<a href=\"favorite.php?ptop=y\">"._MD_FAVORITE_DIRTOP."</a>";
		$sql = "SELECT * FROM ".$T_FDIR." WHERE id='".$dir_id."'";
		$res = mysql_query($sql, $conn);
		if(mysql_num_rows($res) > 0){
			$row = mysql_fetch_array($res, MYSQL_ASSOC);
			$pass = $row["Pass"]."[".$dir_id."]";
			
			# dir map
			$dp = explode("][", $pass);
			for($i=0; $i<count($dp); $i++){
				$dp[$i] = str_replace("[","",$dp[$i]);
				$dp[$i] = str_replace("]","",$dp[$i]);
				$sql = "SELECT * FROM ".$T_FDIR." WHERE id='".$dp[$i]."'";
				$res = mysql_query($sql, $conn);
				$row = mysql_fetch_array($res, MYSQL_ASSOC);
				$dir_map .= "/<a href=\"favorite.php?d_id=".$row["id"]."\">".$row["Name"]."</a>";
			}
			
		}
		echo "<br><div class=\"pt\">".$dir_map."</div>";
		echo "<a href=\"javascript:check()\">"._MD_CHECK_ALL."</a><br><br>";
		echo "<form action=\"".$_SERVER[PHP_SELF]."\" method=\"GET\" name=\"datalist\">";
	
		# favorite data id
		$sql = "SELECT * FROM ".$T_FDATA." WHERE Usr='".$user."' AND dir_id='".$dir_id."'";
		$res = mysql_query($sql, $conn);
		while($row = mysql_fetch_array($res, MYSQL_ASSOC)){
			$f_id = $row["id"];
			$data_id = $row["data_id"];
		
			# get pmid from data id
			$sql2 = "SELECT * FROM ".$T_ID." WHERE id='".$data_id."'";
			$res2 = mysql_query($sql2, $conn);
			$row2 = mysql_fetch_array($res2, MYSQL_ASSOC);

			$pmid = $row2["PMID"];
			$a = $row2["Author"];	$t = $row2["Title"];	$abst = $row2["Abstract"];
			$v = $row2["Volume"];	$p = $row2["Page"];	$y = $row2["Year"];
			$j = $row2["Journal"];	$a_jp = $row2["Author_JP"];	$t_jp = $row2["Title_JP"];

			# get authors from database
			$author="";
			$a = explode(",",substr($a,0,-1));
			for($k=0; $k<count($a); $k++){
				$a[$k] = str_replace("[","",$a[$k]);
				$a[$k] = str_replace("]","",$a[$k]);
				$sql2 = "SELECT Author FROM ".$T_AUTHOR." WHERE id='".$a[$k]."'";
				$res2 = mysql_query($sql2, $conn);
				$row2 = mysql_fetch_array($res2, MYSQL_ASSOC);
				$author.=$row2["Author"].", ";
			}
			$author = substr($author,0,-2);

			# get journal from database
			$sql2 = "SELECT Journal,Journal_JP FROM ".$T_JOURNAL." WHERE id='".$j."'";
			$res2 = mysql_query($sql2, $conn);
			$row2 = mysql_fetch_array($res2, MYSQL_ASSOC);
			$j = $row2["Journal"];
			$j_jp = $row2["Journal_JP"];

			#note
			$memo = "&nbsp;&nbsp;[<a href=\"javascript:disp('include/paper_desc.php?mid=".$pmid."',650,600)\">note ";
			 #private note num
			$sql2 = "SELECT * FROM ".$T_MEMO." WHERE data_id='".$pmid."' AND Public_flg='0' AND R_usr='".$user."'";
			$res2 = mysql_query($sql2, $conn);
			$memo.= "(".mysql_num_rows($res2);
			 #public note num
			$sql2 = "SELECT * FROM ".$T_MEMO." WHERE data_id='".$pmid."' AND Public_flg='1'";
			$res2 = mysql_query($sql2, $conn);
			$memo.= "/".mysql_num_rows($res2).")";
			$memo.= "</a>]";

			# abstract
			$show_ab = "";
			if($abst)	$show_ab = "[<a href=\"javascript:disp('include/paper_desc.php?abst=".$pmid."',500,300)\">Abstract</a>]";
			
			# download
			$show_dl = "";
			if ($pmid > 0) {
				if(file_exists($up_dir.$pmid.".pdf")){
					$show_dl = "[<a href=\"".$up_dir.$pmid.".pdf\" target=\"_blank\">PDF</a>]";
				}
			} else {
				$file_name = $y."_".$author."_".$j."_".$v."_".$p;
				$file_name = str_replace( array(' ', ','), array('_', '~'), $file_name );
				$file_name = $file_name.".pdf";
				if(file_exists("uploads/".$file_name)){
					$show_dl = "[<a href=\"uploads/".$file_name."\" target=\"_blank\">PDF</a>]";
				}
			}
			
			# head color
			($show_dl) ? $class="head" : $class="even";
			
			#id
			if ($pmid > 0 ) {
				$pmid = "<a  target=\"_blank\" href=\"http://www.ncbi.nlm.nih.gov/entrez/query.fcgi?cmd=search&term=".$pmid."\">".$pmid."</a>";
				$pid = "PMID[".$pmid."]";
			} else {
				$pid = "";
			}
	
			if ( strlen($t_jp) ) $title = $t_jp; else $title = $t;
			if ( strlen($a_jp) ) $author = $a_jp;
			if ( strlen($j_jp) ) $journal = $j_jp; else $journal = $j;
			echo <<<E
			<table class="outer" style="width:100%">
			<tr>
				<td rowspan="3" class="head" style="width:20px"><input type="checkbox" name="data[]" value="$f_id"></td>
				<td colspan="2" class="$class">$title</td>
			</tr>
			<tr><td colspan="2" class="even">$author</td></tr>
			<tr>
				<td>$pid $memo</td>
				<td style="text-align:right">$journal &nbsp;$y-v$v-pp$p &nbsp;$show_ab $show_dl</td>
			</tr>
			</table><br>
E;
		}

		# make directory list
		$sql = "SELECT * FROM ".$T_FDIR." WHERE Usr='".$user."' AND Pass='".$pass."'";
		$res = mysql_query($sql, $conn);
		while($row = mysql_fetch_array($res, MYSQL_ASSOC)){
			$d_id[] = $row["id"];
			$d_name[] = $row["Name"];
		}

		$d_id[] = "0";
		$d_name[] = "--------------";
		$d_id[] = "0";
		$d_name[] = "TOP";
		
		$sql = "SELECT * FROM ".$T_FDIR." WHERE Usr='".$user."'";
		$res = mysql_query($sql, $conn);
		while($row = mysql_fetch_array($res, MYSQL_ASSOC)){
			$d_id[] = $row["id"];
			$d_name[] = $row["Name"];
		}
		
		echo "<br><input type=\"radio\" name=\"mv_method\" value=\"biblio\">"._MD_ADD_BIBLIO;
		echo "<br><input type=\"radio\" name=\"mv_method\" value=\"delete\">"._MD_DELETE." ";
		echo "<br><input type=\"radio\" name=\"mv_method\" value=\"insert\">";
		
		if(_MD_INSERTINTO == "insert into") echo _MD_INSERTINTO." ";
		echo "<select name=\"dir\"";
		for($i=0; $i<count($d_id); $i++){
			echo "<option value=\"".$d_id[$i]."\">".$d_name[$i]."</option>";
		}
		echo "</select> ";
		if(_MD_INSERTINTO != "insert into") echo _MD_INSERTINTO;
		
		echo "<br><br><input type=\"submit\" value=\"submit\" name=\"mv_data\">";
		echo "</form>";
	}

?>

==> PPDF_1_2.zip: PubMedPDF/include/favorite_functions.php <==
<?php

# ʸꥹȼ
	function GET_BIBLIO_NUM($user){
		include "conn.php";
		include "../style.php";
		
		$sql = "SELECT * FROM ".$T_TMP." WHERE tmp1='biblio' AND tmp2='".$user."'";
		$res = mysql_query($sql, $conn);
		$num = mysql_num_rows($res);
	
		echo "<br><div class=\"pt\">"._MD_BIBLIO."</div>";
		echo "\"".$num."\" "._MD_BIBLIO_EXIST."&nbsp;&nbsp;&nbsp;";
		echo "[<a href=\"biblio.php\">"._MD_BIBLIO_EXPORT."</a>]<br>";
	}


# Υեɽ
# 桼̾եID

	function GET_FDIR($user, $dir_id){
		include "conn.php";
		include "../style.php";

		$d = "";
		$pass = "";

		# get dir name
		$sql = "SELECT * FROM ".$T_FDIR." WHERE id='".$dir_id."'";
		$res = mysql_query($sql, $conn);
		if(mysql_num_rows($res) > 0){
			$row = mysql_fetch_array($res, MYSQL_ASSOC);
			$d = "(".$row["Name"].")";
			$pass = $row["Pass"]."[".$dir_id."]";
		}

		echo "<br><div class=\"pt\">"._MD_FAVORITE_DIRLIST."</div>";
		$sql = "SELECT * FROM ".$T_FDIR." WHERE Usr='".$user."' AND Pass='".$pass."'";
		$res = mysql_query($sql, $conn);
		while($row = mysql_fetch_array($res, MYSQL_ASSOC)){
			$d_id = $row["id"];
			$d_name = $row["Name"];
			
			$sql2 = "SELECT * FROM ".$T_FDATA." WHERE dir_id='".$d_id."'";
			$res2 = mysql_query($sql2, $conn);
			echo "[<a href=\"favorite.php?deld_id=".$d_id."\"><img src=\"images/delete.png\"></a>] ";
			echo "<a href=\"favorite.php?d_id=".$d_id."\">".$d_name."</a>(".mysql_num_rows($res2).")";
			
			$sql3 = "SELECT * FROM ".$T_FDIR." WHERE Usr='".$user."' AND Pass like '%[".$d_id."]%'";
			$res3 = mysql_query($sql3, $conn);
			if(mysql_num_rows($res3) > 0){
				echo "<table style=\"margin-left:20px\"><tr>";
				$i=0;
				while($row3 = mysql_fetch_array($res3, MYSQL_ASSOC)){
					$sql4 = "SELECT * FROM ".$T_FDATA." WHERE dir_id='".$row3["id"]."'";
					$res4 = mysql_query($sql4, $conn);
					if(!($i % 4)) echo "</tr><tr>";
					echo "<td style=\"width:20%\">";
					echo "[<a href=\"favorite.php?deld_id=".$row3["id"]."\"><img src=\"images/delete.png\"></a>] ";
					echo "<a href=\"favorite.php?d_id=".$row3["id"]."\">".$row3["Name"]."</a>(".mysql_num_rows($res4).")&nbsp;&nbsp;";
					echo "</td>";
					$i++;
				}
				echo "</tr></table><br>";
			}else{
				echo "<br>";
			}
		}
		if($pass != "")	echo "<a href=\"favorite.php?ptop=y\">Top</a><br>";
	}


# Υǡɽ
# 桼̾եID

	function GET_FDATA($user, $dir_id){
	
		include "conn.php";
		include "../style.php";
		include "check_perm.php";

		# upload directory(relative pass)
		$sql = "SELECT * FROM ".$T_CONFIG." WHERE conf_name='updir2'";
		$res = mysql_query($sql, $conn);
		$row = mysql_fetch_array($res, MYSQL_ASSOC);

		$up_dir = $row["conf_value"];
		if(substr($up_dir,-1) != "/") $up_dir.="/";

		# get dir name
		$pass = "";
		$dir_map = "<a href=\"favorite.php?ptop=y\">"._MD_FAVORITE_DIRTOP."</a>";
		$sql = "SELECT * FROM ".$T_FDIR." WHERE id='".$dir_id."'";
		$res = mysql_query($sql, $conn);
		if(mysql_num_rows($res) > 0){
			$row = mysql_fetch_array($res, MYSQL_ASSOC);
			$pass = $row["Pass"]."[".$dir_id."]";
			
			# dir map
			$dp = explode("][", $pass);
			for($i=0; $i<count($dp); $i++){
				$dp[$i] = str_replace("[","",$dp[$i]);
				$dp[$i] = str_replace("]","",$dp[$i]);
				$sql = "SELECT * FROM ".$T_FDIR." WHERE id='".$dp[$i]."'";
				$res = mysql_query($sql, $conn);
				$row = mysql_fetch_array($res, MYSQL_ASSOC);
				$dir_map .= "/<a href=\"favorite.php?d_id=".$row["id"]."\">".$row["Name"]."</a>";
			}
			
		}
		echo "<br><div class=\"pt\">".$dir_map."</div>";
		echo "<a href=\"javascript:check()\">"._MD_CHECK_ALL."</a><br><br>";
		echo "<form action=\"".$_SERVER[PHP_SELF]."\" method=\"GET\" name=\"datalist\">";
	
		# favorite data id
		$sql = "SELECT * FROM ".$T_FDATA." WHERE Usr='".$user."' AND dir_id='".$dir_id."'";
		$res = mysql_query($sql, $conn);
		while($row = mysql_fetch_array($res, MYSQL_ASSOC)){
			$f_id = $row["id"];
			$data_id = $row["data_id"];
		
			# get pmid from data id
			$sql2 = "SELECT * FROM ".$T_ID." WHERE id='".$data_id."'";
			$res2 = mysql_query($sql2, $conn);
			$row2 = mysql_fetch_array($res2, MYSQL_ASSOC);

			$pmid = $row2["PMID"];
			$a = $row2["Author"];	$t = $row2["Title"];	$abst = $row2["Abstract"];
			$v = $row2["Volume"];	$p = $row2["Page"];	$y = $row2["Year"];
			$j = $row2["Journal"];	$a_jp = $row2["Author_JP"];	$t_jp = $row2["Title_JP"];

			# get authors from database
			$author="";
			$a = explode(",",substr($a,0,-1));
			for($k=0; $k<count($a); $k++){
				$a[$k] = str_replace("[","",$a[$k]);
				$a[$k] = str_replace("]","",$a[$k]);
				$sql2 = "SELECT Author FROM ".$T_AUTHOR." WHERE id='".$a[$k]."'";
				$res2 = mysql_query($sql2, $conn);
				$row2 = mysql_fetch_array($res2, MYSQL_ASSOC);
				$author.=$row2["Author"].", ";
			}
			$author = substr($author,0,-2);

			# get journal from database
			$sql2 = "SELECT Journal,Journal_JP FROM ".$T_JOURNAL." WHERE id='".$j."'";
			$res2 = mysql_query($sql2, $conn);
			$row2 = mysql_fetch_array($res2, MYSQL_ASSOC);
			$j = $row2["Journal"];
			$j_jp = $row2["Journal_JP"];

			#note
			$memo = "[<a href=\"javascript:disp('include/paper_desc.php?mid=".$pmid."',650,600)\">note ";
			 #private note num
			$sql2 = "SELECT * FROM ".$T_MEMO." WHERE data_id='".$pmid."' AND Public_flg='0' AND R_usr='".$user."'";
			$res2 = mysql_query($sql2, $conn);
			$memo.= "(".mysql_num_rows($res2);
			 #public note num
			$sql2 = "SELECT * FROM ".$T_MEMO." WHERE data_id='".$pmid."' AND Public_flg='1'";
			$res2 = mysql_query($sql2, $conn);
			$memo.= "/".mysql_num_rows($res2).")";
			$memo.= "</a>]";

			# abstract
			$show_ab = "";
			if($abst)	$show_ab = "[<a href=\"javascript:disp('include/paper_desc.php?abst=".$pmid."',500,300)\">Abstract</a>]";
			
			# download
			$show_dl = "";
			if ($pmid > 0) {
				if(file_exists($up_dir.$pmid.".pdf")){
					$show_dl = "[<a href=\"".$up_dir.$pmid.".pdf\" target=\"_blank\">PDF</a>]";
				}
			} else {
				$file_name = $y."_".$author."_".$j."_".$v."_".$p;
				$file_name = str_replace( array(' ', ','), array('_', '~'), $file_name );
				$file_name = $file_name.".pdf";
				if(file_exists("uploads/".$file_name)){
					$show_dl = "[<a href=\"uploads/".$file_name."\" target=\"_blank\">PDF</a>]";
				}
			}
			
			#xml
			if($pmid > 0){
				$PUB_XML = XOOPS_ROOT_PATH."/modules/PubMedPDF/pubmed_xml/".$pmid.".xml";
				$PUB_XML2 = XOOPS_URL."/modules/PubMedPDF/pubmed_xml/".$pmid.".xml";
				if(file_exists($PUB_XML)){
					$show_xml_dl = "[<a href=\"".$PUB_XML2."\" target=\"_blank\">XML</a>]";
				}
			
			}else{
				$sql2 = "SELECT * FROM ".$T_ID." WHERE PMID='".$pmid."'";
				$res2 = mysql_query($sql2, $conn);
				$row2 = mysql_fetch_array($res2, MYSQL_ASSOC);
				
				$UP_XML = XOOPS_ROOT_PATH."/modules/PubMedPDF/uploads_xml/".$row2["Custom_t1"].".xml";
				$UP_XML2 = XOOPS_URL."/modules/PubMedPDF/uploads_xml/".$row2["Custom_t1"].".xml";
				if(file_exists($UP_XML)){
					$show_xml_dl = "[<a href=\"".$UP_XML2."\" target=\"_blank\">XML</a>]";
				}
			}
		
			# head color
			($show_dl) ? $class="head" : $class="even";
			
			#id
			if ($pmid > 0 ) {
				$pmid = "<a  target=\"_blank\" href=\"http://www.ncbi.nlm.nih.gov/entrez/query.fcgi?cmd=search&term=".$pmid."\">".$pmid."</a>";
				$pid = "PMID[".$pmid."]";
				$edit="";
			} else {
				$pmid = -$pmid;
				if($r_usr == $user){
					$edit = "[<a href=\"edit_wopmid.php?id=$pmid\">remove/edit</a>]";
				}elseif(Check_permission($user)){
					$edit = "[<a href=\"edit_wopmid.php?id=$pmid\">remove/edit</a>]";
				}else{
					$edit = "";
				}
				$pid = "";
			}
	
			if ( strlen($t_jp) ) $title = $t_jp; else $title = $t;
			if ( strlen($a_jp) ) $author = $a_jp;
			if ( strlen($j_jp) ) $journal = $j_jp; else $journal = $j;
			echo <<<E
			<table class="outer" style="width:100%">
			<tr>
				<td rowspan="4" class="head" style="width:20px"><input type="checkbox" name="data[]" value="$f_id"></td>
				<td colspan="2" class="$class">$title</td>
			</tr>
			<tr><td colspan="2" class="even">$author</td></tr>
			<tr><td colspan="2" class="even" style="text-align:right">$journal &nbsp;$y-v$v-pp$p
			</td></tr>
			<tr>
				<td>$pid $edit $favorite $memo</td>
				<td style="text-align:right">
					 $show_ab $show_xml_dl $show_dl
				</td>
			</tr>
			</table>
			<br>
E;
		}

		# make directory list
		$sql = "SELECT * FROM ".$T_FDIR." WHERE Usr='".$user."' AND Pass='".$pass."'";
		$res = mysql_query($sql, $conn);
		while($row = mysql_fetch_array($res, MYSQL_ASSOC)){
			$d_id[] = $row["id"];
			$d_name[] = $row["Name"];
		}

		$d_id[] = "0";
		$d_name[] = "--------------";
		$d_id[] = "0";
		$d_name[] = "TOP";
		
		$sql = "SELECT * FROM ".$T_FDIR." WHERE Usr='".$user."'";
		$res = mysql_query($sql, $conn);
		while($row = mysql_fetch_array($res, MYSQL_ASSOC)){
			$d_id[] = $row["id"];
			$d_name[] = $row["Name"];
		}
		
		echo "<br><input type=\"radio\" name=\"mv_method\" value=\"biblio\">"._MD_ADD_BIBLIO;
		echo "<br><input type=\"radio\" name=\"mv_method\" value=\"delete\">"._MD_DELETE." ";
		echo "<br><input type=\"radio\" name=\"mv_method\" value=\"insert\">";
		
		if(_MD_INSERTINTO == "insert into") echo _MD_INSERTINTO." ";
		echo "<select name=\"dir\"";
		for($i=0; $i<count($d_id); $i++){
			echo "<option value=\"".$d_id[$i]."\">".$d_name[$i]."</option>";
		}
		echo "</select> ";
		if(_MD_INSERTINTO != "insert into") echo _MD_INSERTINTO;
		
		echo "<br><br><input type=\"submit\" value=\"submit\" name=\"mv_data\">";
		echo "</form>";
	}

?>
